@@ -28,7 +28,7 @@ def validate_classifier(configini,seconds,target):
 
     #main loop
     for i in csvList:
-        print('Processing file: ' + os.path.basename(csvList) + ' File ' + fileCounter + ' / ' + str(len(csvList)))
+        print('Processing file: ' + str(i) + ' File ' + str(fileCounter) + ' / ' + str(len(csvList)))
         df = pd.read_csv(i)
         csvname = os.path.basename(i).split('.')[0]
         fps = int(fpsdf['fps'].loc[(fpsdf['Video'] == csvname)])
