@@ -47,6 +47,7 @@ def configure(file_name):
 # Initializes all GUI widgets
 class MainInterface:
     def __init__(self):
+        padding=5
         self.window = Toplevel()
         folder = Frame(self.window)
         folder.grid(row=0, column=1, sticky=N)
@@ -56,16 +57,16 @@ class MainInterface:
         self.button_frame.grid(row=1, column=0)
 
         self.frameNumber = Label(self.button_frame, text="Frame number")
-        self.frameNumber.grid(row=0, column=1)
+        self.frameNumber.grid(row=0, column=1, padx=padding)
         self.forward = Button(self.button_frame, text=">",
                               command=lambda: load_frame(current_frame_number+1, self.window, self.fbox))
-        self.forward.grid(row=1, column=3, sticky=E)
+        self.forward.grid(row=1, column=3, sticky=E, padx=padding)
         self.forward = Button(self.button_frame, text=">>",
                               command=lambda: load_frame(len(frames_in) - 1, self.window, self.fbox))
-        self.forward.grid(row=1, column=4, sticky=E)
+        self.forward.grid(row=1, column=4, sticky=E, padx=padding)
         self.back = Button(self.button_frame, text="<",
                            command=lambda: load_frame(current_frame_number-1, self.window, self.fbox))
-        self.back.grid(row=1, column=1, sticky=W)
+        self.back.grid(row=1, column=1, sticky=W, padx=padding)
         self.back = Button(self.button_frame, text="<<", command=lambda: load_frame(0, self.window, self.fbox))
         self.back.grid(row=1, column=0, sticky=W)
 
